<?php

/**
 * @file
 * Admin for Webform per Email module.
 */

/**
 * Form for creating new permits and sending emails in bulk.
 */
function webform_per_email_bulk_token() {
  $form['webform_per_email_list'] = array(
    '#type' => 'textarea',
    '#title' => t('Enter emails'),
    '#rows' => 5,
    '#required' => TRUE,
  );

  $form['webform_per_email_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Webform Path'),
    '#required' => TRUE,
    '#default_value' => "",
    '#description' => "Please enter path of the webform. E.g. for 'http://example.com/webform/myform', please enter 'webform/myform'",
    '#size' => 250,
    '#maxlength' => 250,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );

  return $form;
}

/**
 * Validator for Form webform_per_email_bulk_token.
 */
function webform_per_email_bulk_token_validate($form, &$form_state) {
  $values = $form_state['values'];
  $path = drupal_get_normal_path($values['webform_per_email_path']);
  if (!drupal_valid_path($path)) {
    form_set_error('webform_per_email_path', 'Enter a valid path alias');
  }
}

/**
 * Submit handler for Form webform_per_email_bulk_token.
 */
function webform_per_email_bulk_token_submit($form, &$form_state) {
  $values = $form_state['values'];
  $path = drupal_get_normal_path($values['webform_per_email_path']);

  $emails = $values['webform_per_email_list'];

  // Replace \n with space to unify the delimiter.
  $emails = str_replace("\n", " ", $emails);

  // Remove multiple spaces with one space to avoid blank emails
  // and spaces at the end and begining.
  $emails = preg_replace('/\s+/', ' ', $emails);
  $emails = trim($emails);

  $emails = explode(" ", $emails);
  $nid = arg(1, $path);

  foreach ($emails as $email) {
    $permit = new WebformPermit(NULL, $email, $nid);
    $permit->save();

    $queue = DrupalQueue::get('webform_permit_outbox_queue');
    $queue_item = array(
      'email' => $email,
      'nid' => $nid,
      'hash' => $permit->getHash(),
    );

    // Calling all modules implementing hook_webform_per_email_mail_alter():
    drupal_alter('webform_per_email_mail', $queue_item);

    $queue->createItem($queue_item);
    drupal_set_message(t('Access to node/%nid for %email added to the webform_permit_outbox_queue', array('%email' => $email, '%nid' => $nid)));
    watchdog("webform_per_email_added", 'Access to node/%nid for %email added to the webform_permit_outbox_queue', array('%email' => $email, '%nid' => $nid), WATCHDOG_INFO);
  }
}

/**
 * Form for Webform per Email settings.
 */
function webform_per_email_settings() {
  $webform_per_email_settings = variable_get('webform_per_email_settings');

  $form['webform_per_email_mail_template'] = array(
    '#type' => 'textarea',
    '#title' => t('Create the mail template'),
    '#rows' => 5,
    '#description' => '@hash',
    '#default_value' => format_string($webform_per_email_settings['mail_template']),
    '#required' => TRUE,
  );

  $form['webform_per_email_mail_cron_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of emails to send per cron run'),
    '#required' => TRUE,
    '#default_value' => isset($webform_per_email_settings['cron_limit']) ? $webform_per_email_settings['cron_limit'] : 25,
    '#description' => t('Number of emails to send per cron run'),
    '#size' => 3,
    '#maxlength' => 3,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );

  return $form;
}

/**
 * Submit Handler for Form webform_per_email_settings.
 */
function webform_per_email_settings_submit($form, &$form_state) {
  $cron_limit = $form_state['values']['webform_per_email_mail_cron_limit'];
  $webform_per_email_settings = array(
    'mail_template' => $form_state['values']['webform_per_email_mail_template'],
    'cron_limit' => is_numeric($cron_limit) ? $cron_limit : 25,
  );
  variable_set('webform_per_email_settings', $webform_per_email_settings);
}
